pub struct FieldInfo(/* private fields */);Expand description
Information about a table field
Implementations
Sourceimpl FieldInfo
impl FieldInfo
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Returns the name of the field
If the field name cannot be represented as UTF-8, returns “<invalid field name>”
Sourcepub fn field_type(&self) -> Result<FieldTypeId, u32>
pub fn field_type(&self) -> Result<FieldTypeId, u32>
Returns the type of the field
If the type cannot be represented as a FieldTypeId, returns an error
with the raw field type value.