pub struct TableInfo(/* private fields */);Expand description
Information about a table
Implementations
Sourceimpl TableInfo
impl TableInfo
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Returns the name of the table
If the table name cannot be represented as UTF-8, returns “<invalid table name>”
Sourcepub fn key_type(&self) -> Result<FieldTypeId, u32>
pub fn key_type(&self) -> Result<FieldTypeId, u32>
Returns the type of the table’s key
If the type cannot be represented as a FieldTypeId, returns an error
with the raw field type value.